@@ -207,7 +207,7 @@ def mock_optimizer(testcase, hidden_units, expected_loss=None):
       hidden_weights_names + hidden_biases_names +
       [LOGITS_WEIGHTS_NAME + ':0', LOGITS_BIASES_NAME + ':0'])
 
-  class _Optimizer(tf.keras.optimizers.Optimizer):
+  class _Optimizer(tf.keras.optimizers.legacy.Optimizer):
 
     def get_updates(self, loss, params):
       trainable_vars = params
@@ -930,7 +930,7 @@ class BaseDNNWarmStartingTest(object):
         hidden_units=[256, 128],
         feature_columns=[city],
         n_classes=4,
-        optimizer=tf.keras.optimizers.SGD(learning_rate=0.0),
+        optimizer=tf.keras.optimizers.legacy.SGD(learning_rate=0.0),
         warm_start_from=dnn_classifier.model_dir)
 
     warm_started_dnn_classifier.train(input_fn=self._input_fn, max_steps=1)
@@ -966,7 +966,7 @@ class BaseDNNWarmStartingTest(object):
     warm_started_dnn_regressor = self._dnn_regressor_fn(
         hidden_units=[256, 128],
         feature_columns=[city],
-        optimizer=tf.keras.optimizers.SGD(learning_rate=0.0),
+        optimizer=tf.keras.optimizers.legacy.SGD(learning_rate=0.0),
         warm_start_from=dnn_regressor.model_dir)
 
     warm_started_dnn_regressor.train(input_fn=self._input_fn, max_steps=1)
@@ -1004,7 +1004,7 @@ class BaseDNNWarmStartingTest(object):
         hidden_units=[256, 128],
         feature_columns=[city],
         n_classes=4,
-        optimizer=tf.keras.optimizers.SGD(learning_rate=0.0),
+        optimizer=tf.keras.optimizers.legacy.SGD(learning_rate=0.0),
         # The provided regular expression will only warm-start the city
         # embedding, not the kernels and biases of the hidden weights.
         warm_start_from=estimator.WarmStartSettings(
@@ -1083,7 +1083,7 @@ class BaseDNNWarmStartingTest(object):
         hidden_units=[256, 128],
         feature_columns=[occupation],
         n_classes=4,
-        optimizer=tf.keras.optimizers.SGD(learning_rate=0.0),
+        optimizer=tf.keras.optimizers.legacy.SGD(learning_rate=0.0),
         warm_start_from=estimator.WarmStartSettings(
             ckpt_to_initialize_from=dnn_classifier.model_dir,
             var_name_to_vocab_info={
@@ -1151,7 +1151,7 @@ class BaseDNNWarmStartingTest(object):
         hidden_units=[256, 128],
         feature_columns=[city],
         n_classes=4,
-        optimizer=tf.keras.optimizers.SGD(learning_rate=0.0),
+        optimizer=tf.keras.optimizers.legacy.SGD(learning_rate=0.0),
         # The 'city' variable correspond to the 'locality' variable in the
         # previous model.
         warm_start_from=estimator.WarmStartSettings(
