@@ -27,8 +27,8 @@ from tensorflow.python.feature_column.feature_column import _LazyBuilder
 from tensorflow.python.feature_column.feature_column import _NumericColumn
 from tensorflow.python.framework import ops
 from tensorflow.python.util import function_utils
-from tensorflow.python.util.tf_export import estimator_export
 from tensorflow_estimator.python.estimator.canned import metric_keys
+from tensorflow_estimator.python.estimator.estimator_export import estimator_export
 from tensorflow_estimator.python.estimator.export import export_output
 
 DEFAULT_SERVING_KEY = tf.saved_model.DEFAULT_SERVING_SIGNATURE_DEF_KEY
@@ -657,11 +657,13 @@ def validate_update_ops(update_ops=None):
         _VALIDATION_ERROR_MSG.format('update_ops', type(update_ops)))
 
 
-def validate_v2_optimizer(optimzier):
-  if not isinstance(optimzier, tf.keras.optimizers.Optimizer):
+def validate_v2_optimizer(optimizer):
+  if not isinstance(
+      optimizer,
+      (tf.keras.optimizers.Optimizer, tf.keras.optimizers.legacy.Optimizer)):
     raise ValueError(
-        'The given optimizer is not a tf.keras.optimizers.Optimizer instance. '
-        'Given: {}'.format(optimzier))
+        'The given optimizer is not a tf.keras.optimizers.Optimizer '
+        f'instance. Received optimizer of type {type(optimizer)}')
 
 
 def validate_trainable_variables(trainable_variables=None):
