@@ -21,10 +21,10 @@ from __future__ import print_function
 import tensorflow as tf
 from tensorflow.python.framework import ops
 from tensorflow.python.ops import lookup_ops
-from tensorflow.python.util.tf_export import estimator_export
 from tensorflow_estimator.python.estimator import model_fn
 from tensorflow_estimator.python.estimator.canned import metric_keys
 from tensorflow_estimator.python.estimator.canned import prediction_keys
+from tensorflow_estimator.python.estimator.estimator_export import estimator_export
 from tensorflow_estimator.python.estimator.export import export_output
 from tensorflow_estimator.python.estimator.head import base_head
 from tensorflow_estimator.python.estimator.mode_keys import ModeKeys
@@ -135,7 +135,7 @@ class MultiClassHead(base_head.Head):
                n_classes,
                weight_column=None,
                label_vocabulary=None,
-               loss_reduction=tf.compat.v2.keras.losses.Reduction.SUM_OVER_BATCH_SIZE,
+               loss_reduction=tf.losses.Reduction.SUM_OVER_BATCH_SIZE,
                loss_fn=None,
                name=None):
     if n_classes is None:
