@@ -21,10 +21,10 @@ from __future__ import print_function
 import tensorflow as tf
 
 from tensorflow.python.framework import ops
-from tensorflow.python.util.tf_export import estimator_export
 from tensorflow_estimator.python.estimator import model_fn
 from tensorflow_estimator.python.estimator.canned import metric_keys
 from tensorflow_estimator.python.estimator.canned import prediction_keys
+from tensorflow_estimator.python.estimator.estimator_export import estimator_export
 from tensorflow_estimator.python.estimator.export import export_output
 from tensorflow_estimator.python.estimator.head import base_head
 from tensorflow_estimator.python.estimator.mode_keys import ModeKeys
@@ -134,7 +134,7 @@ class RegressionHead(base_head.Head):
   def __init__(self,
                label_dimension=1,
                weight_column=None,
-               loss_reduction=tf.compat.v2.keras.losses.Reduction.SUM_OVER_BATCH_SIZE,
+               loss_reduction=tf.losses.Reduction.SUM_OVER_BATCH_SIZE,
                loss_fn=None,
                inverse_link_fn=None,
                name=None):
@@ -477,7 +477,7 @@ class PoissonRegressionHead(RegressionHead):
   def __init__(self,
                label_dimension=1,
                weight_column=None,
-               loss_reduction=tf.compat.v2.keras.losses.Reduction.SUM_OVER_BATCH_SIZE,
+               loss_reduction=tf.losses.Reduction.SUM_OVER_BATCH_SIZE,
                compute_full_loss=True,
                name=None):
     self._compute_full_loss = compute_full_loss
@@ -572,7 +572,7 @@ class LogisticRegressionHead(RegressionHead):
 
   def __init__(self,
                weight_column=None,
-               loss_reduction=tf.compat.v2.keras.losses.Reduction.SUM_OVER_BATCH_SIZE,
+               loss_reduction=tf.losses.Reduction.SUM_OVER_BATCH_SIZE,
                name=None):
     super(LogisticRegressionHead, self).__init__(
         label_dimension=1,
