@@ -21,8 +21,9 @@ from __future__ import print_function
 import collections
 import os
 import re
+from absl import logging
 import tensorflow as tf
-from tensorflow.python.training.tracking import util as trackable_util
+from tensorflow.python.checkpoint import checkpoint as trackable_util
 from tensorflow_estimator.python.estimator import estimator as estimator_lib
 from tensorflow_estimator.python.estimator import model_fn as model_fn_lib
 from tensorflow_estimator.python.estimator.export import export_lib
@@ -304,6 +305,24 @@ def _create_keras_model_fn(keras_model,
   Returns:
     The model_fn for a keras Estimator.
   """
+  if isinstance(keras_model.optimizer,
+                tf.keras.optimizers.experimental.Optimizer):
+    # Experimental optimizer cannot work with estimator, so we convert it to
+    # legacy optimizer.
+    if tf.executing_eagerly():
+      logging.warning(
+          'You are using `tf.keras.optimizers.experimental.Optimizer` in TF '
+          'estimator, which only supports '
+          '`tf.keras.optimizers.legacy.Optimizer`. Automatically converting '
+          'your optimizer to `tf.keras.optimizers.legacy.Optimizer`.')
+      opt = tf.keras.__internal__.optimizers.convert_to_legacy_optimizer(
+          keras_model.optimizer)
+      keras_model.optimizer = opt
+    else:
+      raise ValueError('Please set your optimizer as an instance of '
+                       '`tf.keras.optimizers.legacy.Optimizer`, e.g., '
+                       '`tf.keras.optimizers.legacy.Adam`. Received optimizer '
+                       f'type: {type(keras_model.optimizer)}.')
   # Get optimizer config in the current context (since model_fn is called in the
   # estimator graph and session). OptimizerV2 objects serialize variable/tensor
   # hyperparameters in their configs, resulting to wrong-session errors during
@@ -505,8 +524,6 @@ def _get_file_from_google_storage(keras_model_path, model_dir):
   return file_name
 
 
-# LINT.IfChange
-# TODO(b/139699640): let model_to_estimator only rely on public Keras APIs.
 def model_to_estimator(keras_model=None,
                        keras_model_path=None,
                        custom_objects=None,
@@ -516,7 +533,6 @@ def model_to_estimator(keras_model=None,
                        use_v2_estimator=False,
                        metric_names_map=None,
                        export_outputs=None):
-  # LINT.ThenChange(//tensorflow/python/keras/estimator/__init__.py)
   """Constructs an `Estimator` instance from given keras model.
 
   If you use infrastructure or other tooling that relies on Estimators, you can
@@ -685,7 +701,6 @@ def model_to_estimator(keras_model=None,
     raise ValueError('The given keras model has not been compiled yet. '
                      'Please compile the model with `model.compile()` '
                      'before calling `model_to_estimator()`.')
-
   keras_model_fn = _create_keras_model_fn(
       keras_model, custom_objects, save_object_ckpt, metric_names_map,
       export_outputs)
